@@ -13,17 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo.utils import timeutils
+
+from sahara import context
 from sahara.i18n import _
-from sahara.plugins import utils as u
+from sahara.plugins.general import exceptions as ex
+from sahara.plugins.general import utils as u
 from sahara.plugins.vanilla.hadoop2 import config
-from sahara.plugins.vanilla.hadoop2 import config_helper as c_helper
 from sahara.plugins.vanilla.hadoop2 import run_scripts as run
 from sahara.plugins.vanilla.hadoop2 import utils as pu
 from sahara.plugins.vanilla import utils as vu
-from sahara.swift import swift_helper
-from sahara.utils import cluster_progress_ops as cpo
-from sahara.utils import poll_utils
-
 
 HADOOP_CONF_DIR = config.HADOOP_CONF_DIR
 
@@ -37,18 +36,18 @@ def scale_cluster(pctx, cluster, instances):
         run.refresh_yarn_nodes(cluster)
 
     config.configure_topology_data(pctx, cluster)
-    run.start_dn_nm_processes(instances)
-    swift_helper.install_ssl_certs(instances)
-    config.configure_zookeeper(cluster)
-    run.refresh_zk_servers(cluster)
+    run.start_all_processes(instances, [])
 
 
 def _get_instances_with_service(instances, service):
-    return [instance for instance in instances
-            if service in instance.node_group.node_processes]
+    ret = []
+    for instance in instances:
+        if service in instance.node_group.node_processes:
+            ret.append(instance)
+
+    return ret
 
 
-@cpo.event_wrapper(True, step=_("Update include files"), param=('cluster', 0))
 def _update_include_files(cluster, dec_instances=None):
     dec_instances = dec_instances or []
     dec_instances_ids = [instance.id for instance in dec_instances]
@@ -89,9 +88,6 @@ def decommission_nodes(pctx, cluster, instances):
     run.refresh_hadoop_nodes(cluster)
 
     config.configure_topology_data(pctx, cluster)
-    config.configure_zookeeper(cluster, instances)
-    # TODO(shuyingya):should invent a way to lastly restart the leader node
-    run.refresh_zk_servers(cluster, instances)
 
 
 def _update_exclude_files(cluster, instances):
@@ -118,30 +114,29 @@ def _clear_exclude_files(cluster):
                 'sudo su - -c "echo > %s/nm-exclude" hadoop' % HADOOP_CONF_DIR)
 
 
-def is_decommissioned(cluster, check_func, instances):
-    statuses = check_func(cluster)
-    for instance in instances:
-        if statuses[instance.fqdn()] != 'decommissioned':
-            return False
-    return True
+def _check_decommission(cluster, instances, check_func, timeout):
+    s_time = timeutils.utcnow()
+    while timeutils.delta_seconds(s_time, timeutils.utcnow()) < timeout:
+        statuses = check_func(cluster)
+        dec_ok = True
+        for instance in instances:
+            if statuses[instance.fqdn()] != 'decommissioned':
+                dec_ok = False
+
+        if dec_ok:
+            return
+        else:
+            context.sleep(5)
+    else:
+        ex.DecommissionError(
+            _("Cannot finish decommission of cluster %(cluster)s in "
+              "%(seconds)d seconds") %
+            {"cluster": cluster, "seconds": timeout})
 
 
-def _check_decommission(cluster, instances, check_func, option):
-    poll_utils.plugin_option_poll(
-        cluster, is_decommissioned, option, _("Wait for decommissioning"),
-        5, {'cluster': cluster, 'check_func': check_func,
-            'instances': instances})
-
-
-@cpo.event_wrapper(
-    True, step=_("Decommission %s") % "NodeManagers", param=('cluster', 0))
 def _check_nodemanagers_decommission(cluster, instances):
-    _check_decommission(cluster, instances, pu.get_nodemanagers_status,
-                        c_helper.NODEMANAGERS_DECOMMISSIONING_TIMEOUT)
+    _check_decommission(cluster, instances, pu.get_nodemanagers_status, 300)
 
 
-@cpo.event_wrapper(
-    True, step=_("Decommission %s") % "DataNodes", param=('cluster', 0))
 def _check_datanodes_decommission(cluster, instances):
-    _check_decommission(cluster, instances, pu.get_datanodes_status,
-                        c_helper.DATANODES_DECOMMISSIONING_TIMEOUT)
+    _check_decommission(cluster, instances, pu.get_datanodes_status, 3600 * 4)
