@@ -13,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 import six
 
 from sahara import conductor as c
 from sahara import context
-from sahara.utils.openstack import base as b
+from sahara.openstack.common import log as logging
 from sahara.utils.openstack import neutron
 from sahara.utils.openstack import nova
 
@@ -42,48 +41,41 @@ def init_instances_ips(instance):
     management_ip = None
     internal_ip = None
 
-    for addresses in six.itervalues(server.addresses):
-        # selects IPv4 preferentially
-        for address in sorted(addresses, key=lambda addr: addr['version']):
+    for network_label, addresses in six.iteritems(server.addresses):
+        for address in addresses:
             if address['OS-EXT-IPS:type'] == 'fixed':
                 internal_ip = internal_ip or address['addr']
             else:
                 management_ip = management_ip or address['addr']
 
-    cluster = instance.cluster
-    if (not CONF.use_floating_ips or
-            (cluster.has_proxy_gateway() and
-             not instance.node_group.is_proxy_gateway)):
+    if not CONF.use_floating_ips:
         management_ip = internal_ip
 
     # NOTE(aignatov): Once bug #1262529 is fixed this 'if' block should be
     # reviewed and reformatted again, probably removed completely.
     if CONF.use_neutron and not (management_ip and internal_ip):
-        LOG.debug("Instance doesn't yet contain Floating IP or Internal IP. "
-                  "Floating IP={mgmt_ip}, Internal IP={internal_ip}. "
-                  "Trying to get via Neutron.".format(
-                      mgmt_ip=management_ip, internal_ip=internal_ip))
+        LOG.debug("Instance %s doesn't contain yet Floating IP or Internal IP."
+                  " Floating IP=%s, Internal IP=%s. Trying to get via Neutron."
+                  % (server.name, management_ip, internal_ip))
         neutron_client = neutron.client()
-        ports = b.execute_with_retries(
-            neutron_client.list_ports, device_id=server.id)["ports"]
+        ports = neutron_client.list_ports(device_id=server.id)["ports"]
         if ports:
             target_port_id = ports[0]['id']
-            fl_ips = b.execute_with_retries(
-                neutron_client.list_floatingips,
+            fl_ips = neutron_client.list_floatingips(
                 port_id=target_port_id)['floatingips']
             if fl_ips:
                 fl_ip = fl_ips[0]
                 if not internal_ip:
                     internal_ip = fl_ip['fixed_ip_address']
-                    LOG.debug('Found fixed IP {internal_ip}'
-                              .format(internal_ip=internal_ip))
+                    LOG.debug('Found fixed IP %s for %s' % (internal_ip,
+                                                            server.name))
                 # Zeroing management_ip if Sahara in private network
                 if not CONF.use_floating_ips:
                     management_ip = internal_ip
                 elif not management_ip:
                     management_ip = fl_ip['floating_ip_address']
-                    LOG.debug('Found floating IP {mgmt_ip}'
-                              .format(mgmt_ip=management_ip))
+                    LOG.debug('Found floating IP %s for %s' % (management_ip,
+                                                               server.name))
 
     conductor.instance_update(context.ctx(), instance,
                               {"management_ip": management_ip,
@@ -93,13 +85,11 @@ def init_instances_ips(instance):
 
 
 def assign_floating_ip(instance_id, pool):
-    ip = b.execute_with_retries(nova.client().floating_ips.create, pool)
-    server = b.execute_with_retries(nova.client().servers.get, instance_id)
-    b.execute_with_retries(server.add_floating_ip, ip)
+    ip = nova.client().floating_ips.create(pool)
+    nova.client().servers.get(instance_id).add_floating_ip(ip)
 
 
 def delete_floating_ip(instance_id):
-    fl_ips = b.execute_with_retries(
-        nova.client().floating_ips.findall, instance_id=instance_id)
+    fl_ips = nova.client().floating_ips.findall(instance_id=instance_id)
     for fl_ip in fl_ips:
-        b.execute_with_retries(nova.client().floating_ips.delete, fl_ip.id)
+        nova.client().floating_ips.delete(fl_ip.id)
