@@ -14,7 +14,6 @@
 # limitations under the License.
 
 from testtools import testcase
-import unittest2
 
 from sahara.tests.integration.configs import config as cfg
 from sahara.tests.integration.tests import base as b
@@ -24,7 +23,7 @@ from sahara.tests.integration.tests import edp
 from sahara.tests.integration.tests import map_reduce
 from sahara.tests.integration.tests import scaling
 from sahara.tests.integration.tests import swift
-from sahara.utils import files as f
+from sahara.utils import edp as utils_edp
 
 
 class VanillaTwoGatingTest(cluster_configs.ClusterConfigTest,
@@ -41,20 +40,22 @@ class VanillaTwoGatingTest(cluster_configs.ClusterConfigTest,
 
     def setUp(self):
         super(VanillaTwoGatingTest, self).setUp()
+        self.cluster_id = None
+        self.cluster_template_id = None
+        self.ng_template_ids = []
 
+    def _prepare_test(self):
         self.vanilla_two_config = cfg.ITConfig().vanilla_two_config
         self.floating_ip_pool = self.common_config.FLOATING_IP_POOL
         self.internal_neutron_net = None
         if self.common_config.NEUTRON_ENABLED:
             self.internal_neutron_net = self.get_internal_neutron_net_id()
-            self.floating_ip_pool = \
-                self.get_floating_ip_pool_id_for_neutron_net()
+            self.floating_ip_pool = (
+                self.get_floating_ip_pool_id_for_neutron_net())
 
-        self.cluster_id = None
-        self.cluster_template_id = None
-        self.ng_template_ids = []
-        self.vanilla_two_config.IMAGE_ID, self.vanilla_two_config.SSH_USERNAME\
-            = (self.get_image_id_and_ssh_username(self.vanilla_two_config))
+        (self.vanilla_two_config.IMAGE_ID,
+         self.vanilla_two_config.SSH_USERNAME) = (
+            self.get_image_id_and_ssh_username(self.vanilla_two_config))
 
         self.volumes_per_node = 0
         self.volume_size = 0
@@ -127,7 +128,8 @@ class VanillaTwoGatingTest(cluster_configs.ClusterConfigTest,
                 {
                     'name': 'master-node-oo-hs',
                     'flavor_id': self.flavor_id,
-                    'node_processes': ['oozie', 'historyserver'],
+                    'node_processes': ['oozie', 'historyserver',
+                                       'secondarynamenode'],
                     'floating_ip_pool': self.floating_ip_pool,
                     'count': 1
                 },
@@ -181,50 +183,50 @@ class VanillaTwoGatingTest(cluster_configs.ClusterConfigTest,
 
     @b.errormsg("Failure while EDP testing: ")
     def _check_edp(self):
-        self._edp_test()
+        skipped_edp_job_types = self.vanilla_two_config.SKIP_EDP_JOB_TYPES
 
-    def _edp_test(self):
-        path = 'tests/integration/tests/resources/'
+        if utils_edp.JOB_TYPE_PIG not in skipped_edp_job_types:
+            self._edp_pig_test()
+        if utils_edp.JOB_TYPE_MAPREDUCE not in skipped_edp_job_types:
+            self._edp_mapreduce_test()
+        if utils_edp.JOB_TYPE_MAPREDUCE_STREAMING not in skipped_edp_job_types:
+            self._edp_mapreduce_streaming_test()
+        if utils_edp.JOB_TYPE_JAVA not in skipped_edp_job_types:
+            self._edp_java_test()
 
-        # check pig
-        pig_job = f.get_file_text(path + 'edp-job.pig')
-        pig_lib = f.get_file_text(path + 'edp-lib.jar')
-        self.edp_testing('Pig', [{'pig': pig_job}], [{'jar': pig_lib}])
+    def _edp_pig_test(self):
 
-        # check mapreduce
-        mapreduce_jar = f.get_file_text(path + 'edp-mapreduce.jar')
-        mapreduce_configs = {
-            'configs': {
-                'mapred.mapper.class': 'org.apache.oozie.example.SampleMapper',
-                'mapred.reducer.class':
-                'org.apache.oozie.example.SampleReducer'
-            }
-        }
-        self.edp_testing('MapReduce', [], [{'jar': mapreduce_jar}],
-                         mapreduce_configs)
+        pig_job = self.edp_info.read_pig_example_script()
+        pig_lib = self.edp_info.read_pig_example_jar()
 
-        # check mapreduce streaming
-        mapreduce_streaming_configs = {
-            'configs': {
-                'edp.streaming.mapper': '/bin/cat',
-                'edp.streaming.reducer': '/usr/bin/wc'
-            }
-        }
+        self.edp_testing(job_type=utils_edp.JOB_TYPE_PIG,
+                         job_data_list=[{'pig': pig_job}],
+                         lib_data_list=[{'jar': pig_lib}],
+                         swift_binaries=True,
+                         hdfs_local_output=True)
 
-        self.edp_testing('MapReduce.Streaming', [], [],
-                         mapreduce_streaming_configs)
+    def _edp_mapreduce_test(self):
+        mapreduce_jar = self.edp_info.read_mapreduce_example_jar()
+        mapreduce_configs = self.edp_info.mapreduce_example_configs()
+        self.edp_testing(job_type=utils_edp.JOB_TYPE_MAPREDUCE,
+                         job_data_list=[],
+                         lib_data_list=[{'jar': mapreduce_jar}],
+                         configs=mapreduce_configs,
+                         swift_binaries=True,
+                         hdfs_local_output=True)
 
-        # check java
-        java_jar = f.get_file_text(
-            path + 'hadoop-mapreduce-examples-2.3.0.jar')
-        java_configs = {
-            'configs': {
-                'edp.java.main_class':
-                'org.apache.hadoop.examples.QuasiMonteCarlo'
-            },
-            'args': ['10', '10']
-        }
-        self.edp_testing('Java', [], lib_data_list=[{'jar': java_jar}],
+    def _edp_mapreduce_streaming_test(self):
+        self.edp_testing(job_type=utils_edp.JOB_TYPE_MAPREDUCE_STREAMING,
+                         job_data_list=[],
+                         lib_data_list=[],
+                         configs=self.edp_info.mapreduce_streaming_configs())
+
+    def _edp_java_test(self):
+        java_jar = self.edp_info.read_java_example_lib(2)
+        java_configs = self.edp_info.java_example_configs(2)
+        self.edp_testing(utils_edp.JOB_TYPE_JAVA,
+                         job_data_list=[],
+                         lib_data_list=[{'jar': java_jar}],
                          configs=java_configs)
 
     @b.errormsg("Failure while cluster scaling: ")
@@ -276,13 +278,14 @@ class VanillaTwoGatingTest(cluster_configs.ClusterConfigTest,
 
     @b.errormsg("Failure while EDP testing after cluster scaling: ")
     def _check_edp_after_scaling(self):
-        self._edp_test()
+        self._check_edp()
 
-    @unittest2.skipIf(
+    @testcase.skipIf(
         cfg.ITConfig().vanilla_two_config.SKIP_ALL_TESTS_FOR_PLUGIN,
         "All tests for Vanilla plugin were skipped")
     @testcase.attr('vanilla2')
     def test_vanilla_two_plugin_gating(self):
+        self._prepare_test()
         self._create_nm_dn_ng_template()
         self._create_nm_ng_template()
         self._create_dn_ng_template()
