@@ -15,25 +15,32 @@
 
 import mock
 import pkg_resources as pkg
-import unittest2
+import testtools
 
 from sahara.conductor import resource as r
+from sahara.plugins import base as pb
 from sahara.plugins.general import exceptions as ex
 from sahara.plugins.hdp import ambariplugin as ap
 from sahara.plugins.hdp import clusterspec as cs
+from sahara.tests.unit import base as sahara_base
 import sahara.tests.unit.plugins.hdp.hdp_test_base as base
+from sahara.utils import edp
 from sahara import version
 
 
-GET_REST_REQ = "sahara.plugins.hdp.versions.version_1_3_2.versionhandler." \
-               "AmbariClient._get_http_session"
+GET_REST_REQ = ("sahara.plugins.hdp.versions.version_1_3_2.versionhandler."
+                "AmbariClient._get_http_session")
 
 
 def create_cluster_template(ctx, dct):
     return r.ClusterTemplateResource(dct)
 
 
-class AmbariPluginTest(unittest2.TestCase):
+class AmbariPluginTest(sahara_base.SaharaTestCase):
+    def setUp(self):
+        super(AmbariPluginTest, self).setUp()
+        pb.setup_plugins()
+
     def test_get_node_processes(self):
         plugin = ap.AmbariPlugin()
         service_components = plugin.get_node_processes('1.3.2')
@@ -89,8 +96,7 @@ class AmbariPluginTest(unittest2.TestCase):
         self.assertIn('HBASE_REGIONSERVER', components)
         self.assertIn('HBASE_CLIENT', components)
 
-    @mock.patch("sahara.context.ctx")
-    def test_convert(self, ctx_func):
+    def test_convert(self):
         plugin = ap.AmbariPlugin()
         cluster_config_file = pkg.resource_string(
             version.version_info.package,
@@ -214,6 +220,7 @@ class AmbariPluginTest(unittest2.TestCase):
         self.assertEqual('admin', ambari_info.password)
 
     @mock.patch(GET_REST_REQ)
+    @testtools.skip("test failure because of #1325108")
     def test__set_ambari_credentials__no_admin_user(self, client):
         self.requests = []
         plugin = ap.AmbariPlugin()
@@ -234,9 +241,10 @@ class AmbariPluginTest(unittest2.TestCase):
 
         ambari_info = ap.AmbariInfo(TestHost('111.11.1111'),
                                     '8080', 'admin', 'old-pwd')
+
         self.assertRaises(ex.HadoopProvisionError,
-                          plugin._set_ambari_credentials(cluster_spec,
-                                                         ambari_info, '1.3.2'))
+                          plugin._set_ambari_credentials,
+                          cluster_spec, ambari_info, '1.3.2')
 
     @mock.patch("sahara.utils.openstack.nova.get_instance_info",
                 base.get_instance_info)
@@ -260,13 +268,13 @@ class AmbariPluginTest(unittest2.TestCase):
         cluster_config.create_operational_config(cluster, [])
         plugin = ap.AmbariPlugin()
 
-        #change port
+        # change port
         cluster_config.configurations['ambari']['server.port'] = '9000'
 
         ambari_info = plugin.get_ambari_info(cluster_config)
         self.assertEqual('9000', ambari_info.port)
 
-        #remove port
+        # remove port
         del cluster_config.configurations['ambari']['server.port']
         ambari_info = plugin.get_ambari_info(cluster_config)
 
@@ -297,15 +305,41 @@ class AmbariPluginTest(unittest2.TestCase):
             'ng1', [test_host], ["AMBARI_SERVER", "NAMENODE", "DATANODE",
                                  "JOBTRACKER", "TASKTRACKER", "OOZIE_SERVER"])
         cluster = base.TestCluster([node_group])
+        cluster.hadoop_version = '2.0.6'
         plugin = ap.AmbariPlugin()
 
-        self.assertIsNotNone(plugin.get_oozie_server(cluster))
+        self.assertIsNotNone(plugin.get_edp_engine(
+            cluster, edp.JOB_TYPE_PIG).get_oozie_server(cluster))
 
         node_group = base.TestNodeGroup(
             'ng1', [test_host], ["AMBARI_SERVER", "NAMENODE", "DATANODE",
                                  "JOBTRACKER", "TASKTRACKER", "NOT_OOZIE"])
         cluster = base.TestCluster([node_group])
-        self.assertIsNone(plugin.get_oozie_server(cluster))
+        cluster.hadoop_version = '2.0.6'
+        self.assertIsNone(plugin.get_edp_engine(
+            cluster, edp.JOB_TYPE_PIG).get_oozie_server(cluster))
+
+    @mock.patch('sahara.service.edp.hdfs_helper.create_dir_hadoop1')
+    def test_edp132_calls_hadoop1_create_dir(self, create_dir):
+        cluster = base.TestCluster([])
+        cluster.plugin_name = 'hdp'
+        cluster.hadoop_version = '1.3.2'
+        plugin = ap.AmbariPlugin()
+        plugin.get_edp_engine(cluster, edp.JOB_TYPE_PIG).create_hdfs_dir(
+            mock.Mock(), '/tmp')
+
+        self.assertEqual(1, create_dir.call_count)
+
+    @mock.patch('sahara.service.edp.hdfs_helper.create_dir_hadoop2')
+    def test_edp206_calls_hadoop2_create_dir(self, create_dir):
+        cluster = base.TestCluster([])
+        cluster.plugin_name = 'hdp'
+        cluster.hadoop_version = '2.0.6'
+        plugin = ap.AmbariPlugin()
+        plugin.get_edp_engine(cluster, edp.JOB_TYPE_PIG).create_hdfs_dir(
+            mock.Mock(), '/tmp')
+
+        self.assertEqual(1, create_dir.call_count)
 
     def _get_test_request(self, host, port):
         request = base.TestRequest()
